-- ----------------------------
-- 访问日志表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_access_log`;
CREATE TABLE mortals_xhx_access_log(
    `id` bigint(20) NOT NULL    COMMENT '主键ID',
    `traceID` varchar(64)     COMMENT 'TraceId',
    `pspanId` int(9)     COMMENT '父服务调用id',
    `spanId` int(9)     COMMENT '当前服务跨度Id',
    `appName` varchar(64)     COMMENT '应用名称',
    `hostName` varchar(64)     COMMENT '实例IP',
    `targetServer` varchar(64)     COMMENT '目标服务',
    `logLevel` varchar(64)     COMMENT '日志等级',
    `requestIp` varchar(64)     COMMENT '请求者IP',
    `method` varchar(64)     COMMENT '请求方式',
    `schema` varchar(64)     COMMENT '协议',
    `ua` varchar(64)     COMMENT '用户浏览器UA',
    `uri` varchar(64)     COMMENT '请求URI',
    `requestData` varchar(2048)     COMMENT '请求参数，json序列化',
    `responseData` mediumtext     COMMENT '响应结果,',
    `logTime` datetime NOT NULL    COMMENT '日志产生时间',
    `requestTime` datetime     COMMENT '请求时间',
    `responseTime` datetime     COMMENT '响应时间',
    `duration` bigint(20)     COMMENT '持续时间，单位毫秒',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='访问日志';



-- ----------------------------
-- 业务日志表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_biz_log`;
CREATE TABLE mortals_xhx_biz_log(
    `id` bigint(20)     COMMENT '主键ID',
    `traceID` varchar(64)     COMMENT '追踪Id',
    `appName` varchar(64)     COMMENT '应用名称',
    `hostName` varchar(64)     COMMENT '实例IP',
    `logLevel` varchar(64)     COMMENT '日志等级',
    `userCode` varchar(64)     COMMENT '用户唯一标识',
    `deviceCode` varchar(64)     COMMENT '设备唯一标识',
    `eventTopic` varchar(64)     COMMENT '记录埋点的事件主题，方便实时计算或同步进行数据筛选',
    `eventTopicName` varchar(64)     COMMENT '记录埋点中文名称',
    `msg` mediumtext     COMMENT '事件参数，json',
    `logTime` datetime NOT NULL    COMMENT '日志产生时间',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='业务日志';

-- ----------------------------
-- 异常日志表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_error_log`;
CREATE TABLE mortals_xhx_error_log(
    `id` bigint(20)     COMMENT '主键ID',
    `traceID` varchar(64)     COMMENT '追踪Id',
    `appName` varchar(64)     COMMENT '应用名称，宿主客户端运行唯一标识。',
    `hostName` varchar(64)     COMMENT '主机名',
    `message` varchar(1024)     COMMENT '消息标识，如用户登录异常。',
    `platform` varchar(64)     COMMENT '当前客户端使用平台(java,php,c#,android,vue,webos,ios,python)',
    `culprit` varchar(2048)     COMMENT '主要导致异常函数或方法调用名称及入参',
    `tags` varchar(256)     COMMENT '异常事件标记，多个逗号分隔。用以归集异常事件种类。',
    `level` varchar(64)     COMMENT '等级(FATAL，ERROR,WARNING,INFO,DEBUG)',
    `environment` varchar(1024)     COMMENT '客户端运行环境变量信息',
    `releaseVersion` varchar(64)     COMMENT '客户端运行版本信息',
    `fingerprint` varchar(64)     COMMENT '指纹标识，对于相同异常事件归集数量使用。',
    `threadNo` varchar(64)     COMMENT '线程号',
    `checkNum` int(4)     COMMENT '针对同一个异常事件，数量加1',
    `errorStack` text     COMMENT '异常堆栈信息',
    `context` text     COMMENT '上下文信息，如js中发送异常事件，定位源码中信息。',
    `extra` varchar(2048)     COMMENT '扩展信息',
    `logTime` datetime     COMMENT '日志时间',
    `createUserId` bigint(20)     COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
    `updateTime` datetime     COMMENT '更新时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='异常日志';




-- ----------------------------
-- 平台用户操作日志业务表
-- ----------------------------
DROP TABLE IF EXISTS `mortals_xhx_operate_log`;
CREATE TABLE mortals_xhx_operate_log(
    `id` bigint(20)     COMMENT '主键ID',
    `platformMark` varchar(50)     COMMENT '平台标识',
    `userId` bigint(20)     COMMENT '用户id',
    `userName` varchar(50)     COMMENT '用户名称',
    `loginName` varchar(50)     COMMENT '用户登录名',
    `requestUrl` varchar(200)     COMMENT '请求地址',
    `content` varchar(2048)     COMMENT '操作内容，记录操作具体信息，如修改前修改或的数据',
    `ip` varchar(30)     COMMENT '操作IP地址',
    `logDate` datetime     COMMENT '操作时间',
    `operType` tinyint(2)     COMMENT '操作类型，0：新增，1：修改，2：删除',
    `createUserId` bigint(20) NOT NULL    COMMENT '创建用户',
    `createTime` datetime NOT NULL    COMMENT '创建时间',
PRIMARY KEY  (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='平台用户操作日志业务';

